@@ -1,16 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2020-2023 -- leonerd@leonerd.org.uk
 
-package Test::ExpectAndCheck::Future;
+package Test::ExpectAndCheck::Future 0.06;
 
-use strict;
+use v5.14;
 use warnings;
 use base qw( Test::ExpectAndCheck );
 
-our $VERSION = '0.05';
-
 use constant EXPECTATION_CLASS => "Test::ExpectAndCheck::Future::_Expectation";
 
 =head1 NAME
